NAME
Win32::ShellExt - Perl module for implementing context menu extensions of the Windows Explorer
SYNOPSIS
# Sample usage of that module:
package Win32::ShellExt::CopyHook::Txt;
use strict;
use Win32::ShellExt::CopyHook;
$Win32::ShellExt::CopyHook::Txt::VERSION='0.1';
@Win32::ShellExt::CopyHook::Txt::ISA=qw(Win32::ShellExt::CopyHook);
sub get_info_tip() {
my $self = shift;
"text file";
}
sub hkeys() {
my $h = {
"CLSID" => "{7952ADC6-C81A-4A95-8605-732F97535CA7}",
"extension" => "txt",
"package" => "Win32::ShellExt::CopyHook::Txt"
};
$h;
}
1;
DESCRIPTION
This module is never used directly. You always subclass it into your own package, then do a one-time invocation of the install() method on your package (to install the needed registry keys). Then you should have a new entry in the contextual menu of the Windows explorer (the files for which this menu entry appears depend on the filtering you do in the query_context_menu method), and your action() method gets called upon clicking the corresponding menu command in the Explorer.
EXPORT
None by default. None needed.
AUTHOR
Jean-Baptiste Nivoit <jbnivoit@hotmail.com>
SEE ALSO
perl.